import webdriver from '../packages/wdio-protocols/src/protocols/webdriver.js'
import webdriverBidi from '../packages/wdio-protocols/src/protocols/webdriverBidi.js'
import appium from '../packages/wdio-protocols/src/protocols/appium.js'
import mjsonwp from '../packages/wdio-protocols/src/protocols/mjsonwp.js'
import chromium from '../packages/wdio-protocols/src/protocols/chromium.js'
import gecko from '../packages/wdio-protocols/src/protocols/gecko.js'
import saucelabs from '../packages/wdio-protocols/src/protocols/saucelabs.js'
import selenium from '../packages/wdio-protocols/src/protocols/selenium.js'
import jsonwp from '../packages/wdio-protocols/src/protocols/jsonwp.js'

import type { Protocol } from '../packages/wdio-protocols/src/types.js'

export const PROTOCOL_NAMES = {
    appium: 'Appium',
    chromium: 'Chromium',
    gecko: 'Firefox',
    jsonwp: 'JSON Wire Protocol',
    mjsonwp: 'Mobile JSON Wire Protocol',
    saucelabs: 'Sauce Labs',
    selenium: 'Selenium Standalone',
    webdriver: 'WebDriver Protocol',
    webdriverBidi: 'WebDriver Bidi Protocol'
}

export type { Protocol }
export type ProtocolKeys = keyof typeof PROTOCOL_NAMES
export type Protocols = Record<ProtocolKeys, Protocol>

export const PROTOCOLS: Protocols = {
    appium, chromium, gecko, jsonwp, mjsonwp,
    saucelabs, selenium, webdriver, webdriverBidi
}

export const MOBILE_PROTOCOLS = ['appium', 'mjsonwp']
export const VENDOR_PROTOCOLS = ['chromium']
export const IGNORED_SUBPACKAGES_FOR_DOCS = [
    'eslint-plugin-wdio',
    'wdio-smoke-test-service',
    'wdio-smoke-test-reporter',
    'wdio-smoke-test-cjs-service'
]

export const EDIT_WARNING = `// -------------------- ATTENTION --------------------
// Do not edit this file as it gets auto-generated!
// For edits modify /scripts/templates/*.tpl.d.ts
// Check CONTRIBUTING.md for more details.
// --------------------------------------------------
//
`

export const SAUCE_API_DESCRIPTION = `
All commands are only supported on Chrome using Sauce Labs
[Extended Debugging](https://wiki.saucelabs.com/pages/viewpage.action?pageId=70072943)
capabilities. You can enable these by setting the following Sauce options:\n\n
\`\`\`js
{
    browserName: 'Chrome',
    browserVersion: 'latest',
    platformName: 'Windows 10',
    'sauce:options': {
        extendedDebugging: true
    }
}
\`\`\`
`

export const JSONWP_API_DESCRIPTION = `
:::caution depcrecated

The JSONWireProtocol is decrecated and replaced by the [WebDriver](/docs/api/webdriver)
protocol.

:::
`

export const PROTOCOL_API_DESCRIPTION = {
    'saucelabs': SAUCE_API_DESCRIPTION,
    'jsonwp': JSONWP_API_DESCRIPTION
}
